@@ -1,6 +1,6 @@
 from typing import Set, Dict
 from ..exceptions import BakerError
-from ..step_definition import StepDefinition, FileRef
+from ..transform import Transform, FileRef
 
 
 def _map_names(name_set: Set[str], mapping: Dict[str, str]):
@@ -30,37 +30,36 @@ def _invert_mapping(mapping: Dict[str, str]):
     return result
 
 
-def map_tags(base_step: StepDefinition, input_mapping={}, output_mapping={}):
-    extra_input_keys = set(input_mapping.values()) - base_step.input_file_set
+def map_tags(base_step: Transform, input_mapping={}, output_mapping={}):
+    extra_input_keys = set(input_mapping.values()) - base_step.input_tags
     if len(extra_input_keys) > 0:
         msg = "Unexpected key(s) for input mapping: {}".format(
             ", ".join(extra_input_keys)
         )
         raise BakerError(msg)
 
-    extra_output_keys = set(output_mapping) - base_step.output_file_set
+    extra_output_keys = set(output_mapping) - base_step.output_tags
     if len(extra_output_keys) > 0:
         msg = "Unexpected key(s) for output mapping: {}".format(
             ", ".join(extra_output_keys)
         )
         raise BakerError(msg)
 
-    mapping_input_file_set = _map_names(
-        base_step.input_file_set, _invert_mapping(input_mapping)
+    mapping_input_tags = _map_names(
+        base_step.input_tags, _invert_mapping(input_mapping)
     )
-    mapping_output_file_set = _map_names(base_step.output_file_set, output_mapping)
+    mapping_output_tags = _map_names(base_step.output_tags, output_mapping)
 
-    class TagMapping(StepDefinition):
-        nonlocal mapping_input_file_set, mapping_output_file_set, base_step, input_mapping, output_mapping
-        input_file_set = mapping_input_file_set
-        output_file_set = mapping_output_file_set
+    class TagMapping(Transform):
+        nonlocal mapping_input_tags, mapping_output_tags, base_step, input_mapping, output_mapping
+        input_tags = mapping_input_tags
+        output_tags = mapping_output_tags
 
         _base_step = base_step
         _input_mapping = input_mapping
         _output_mapping = output_mapping
 
-        def script(self):
-
+        def script(self, runtime):
             input_paths = _map_filerefs_to_new_paths(
                 self.input_files, self._input_mapping
             )
@@ -69,7 +68,7 @@ def map_tags(base_step: StepDefinition, input_mapping={}, output_mapping={}):
             )
 
             self._base_step(input_paths=input_paths, output_paths=output_paths).build(
-                overwrite=True
+                runtime
             )
 
     return TagMapping
